pub enum TypeChangeOperation {
PromoteColumnType,
DataWrite {
mode: TypeChangeWriteMode,
},
}Expand description
The operation that attempted an unsupported column type change.
Variants
PromoteColumnType
Explicit metadata-only schema evolution through promote_column_type.
DataWrite
A data write tried to change the type of an existing same-name column.
Fields

mode: TypeChangeWriteModeTrait Implementations
Sourceimpl Clone for TypeChangeOperation
impl Clone for TypeChangeOperation
Sourcefn clone(&self) -> TypeChangeOperation
fn clone(&self) -> TypeChangeOperation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TypeChangeOperation
Sourceimpl Debug for TypeChangeOperation
impl Debug for TypeChangeOperation
Sourceimpl Display for TypeChangeOperation
impl Display for TypeChangeOperation
impl Eq for TypeChangeOperation
Sourceimpl PartialEq for TypeChangeOperation
impl PartialEq for TypeChangeOperation
impl StructuralPartialEq for TypeChangeOperation